==> openGion6.8.1.0_core.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/07/18 08:41:26                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    VARCHAR (  10 )         NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                 NOT NULL                                                /*  20 予約番号     */
 , EXECID       VARCHAR (  20 )         NOT NULL                                                /*  30 処理ID       */
 , FGTKAN       VARCHAR (   1 )         NOT NULL                                                /*  40 取込完了ﾌﾗｸﾞ */
 , TMSTR        VARCHAR (  14 )         NOT NULL                                                /*  50 開始時刻     */
 , TMEND        VARCHAR (  14 )                                                                 /*  60 完了時刻     */
 , FILE_IN      VARCHAR ( 255 )                                                                 /*  70 取込ﾌｧｲﾙ     */
 , FILE_OK      VARCHAR ( 255 )                                                                 /*  80 処理済OKﾌｧｲﾙ */
 , FILE_NG      VARCHAR ( 255 )                                                                 /*  90 処理済NGﾌｧｲﾙ */
 , UNIQ         BIGINT                  NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )         NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                 /* 890 更新者       */
);

==> openGion6.8.4.1_core.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/07/31 15:48:44                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    VARCHAR (  10 )         NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                 NOT NULL                                                /*  20 予約番号     */
 , EXECID       VARCHAR (  20 )         NOT NULL                                                /*  30 処理ID       */
 , FGTKAN       VARCHAR (   1 )         NOT NULL                                                /*  40 取込完了ﾌﾗｸﾞ */
 , TMSTR        VARCHAR (  14 )         NOT NULL                                                /*  50 開始時刻     */
 , TMEND        VARCHAR (  14 )                                                                 /*  60 完了時刻     */
 , FILE_IN      VARCHAR ( 255 )                                                                 /*  70 取込ﾌｧｲﾙ     */
 , FILE_OK      VARCHAR ( 255 )                                                                 /*  80 処理済OKﾌｧｲﾙ */
 , FILE_NG      VARCHAR ( 255 )                                                                 /*  90 処理済NGﾌｧｲﾙ */
 , SUTORI       INTEGER                 NOT NULL                                                /* 100 取込件数     */
 , ERRMSG       TEXT                                                                            /* 110 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         BIGINT                  NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )         NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                 /* 890 更新者       */
);
